@@ -14,7 +14,8 @@ import subprocess
 import numpy as np
 import pandas as pd
 
-from .ops import dict_to_dataframe
+from ._cache import _ENGLISH_WRITTEN_NUMBERS
+from .ops import dict_to_dataframe, find_executable
 
 """ == Basic processing of textual data ====================================================== """
 
@@ -65,13 +66,13 @@ def get_acronym(text, only_capitals=False, capitals_in_words=False):
     return acronym
 
 
-def remove_punctuation(x, rm_whitespace=False):
+def remove_punctuation(x, rm_whitespace=True):
     """
     Remove punctuation from string-type data.
 
     :param x: raw string-type data
     :type x: str
-    :param rm_whitespace: whether to remove whitespace, defaults to ``False``
+    :param rm_whitespace: whether to remove whitespace, defaults to ``True``
     :type rm_whitespace: bool
     :return: text with punctuation removed
     :rtype: str
@@ -80,27 +81,31 @@ def remove_punctuation(x, rm_whitespace=False):
 
         >>> from pyhelpers.text import remove_punctuation
 
-        >>> raw_text = 'Hello\tworld! :-)'
+        >>> raw_text = 'Hello\tworld! This is a test. :-)'
 
         >>> text = remove_punctuation(raw_text)
         >>> text
-        'Hello\tworld '
+        'Hello\tworld  This is a test'
 
         >>> text = remove_punctuation(raw_text, rm_whitespace=True)
         >>> text
-        'Hello world'
+        'Hello world This is a test'
     """
 
+    x_ = re.sub(r'[^\w\s]', ' ', x)
+
     # noinspection PyBroadException
     try:
-        y = x.translate(str.maketrans('', '', string.punctuation))
+        y = x_.translate(str.maketrans('', '', string.punctuation))
     except Exception:
-        y = ''.join(p for p in x if p not in string.punctuation)
+        y = ''.join(y_ for y_ in x_ if y_ not in string.punctuation)
+
+    z = y.strip()
 
     if rm_whitespace:
-        y = ' '.join(y.split())
+        z = ' '.join(z.split())
 
-    return y
+    return z
 
 
 def extract_words1upper(x, join_with=None):
@@ -141,6 +146,58 @@ def extract_words1upper(x, join_with=None):
     return extracted_words
 
 
+def numeral_english_to_arabic(x):
+    """
+    Convert a string which potentially is a number written in English to an Arabic number
+
+    :param x: a number written in English
+    :type x: str
+    :return: a number written in Arabic
+    :rtype: int
+
+    **Examples**::
+
+        >>> from pyhelpers.text import numeral_english_to_arabic
+
+        >>> numeral_english_to_arabic('one')
+        1
+
+        >>> numeral_english_to_arabic('one hundred and one')
+        101
+
+        >>> numeral_english_to_arabic('a thousand two hundred and three')
+        1203
+
+        >>> numeral_english_to_arabic('200 and five')
+        205
+
+        >>> numeral_english_to_arabic('Two hundred and fivety')  # Two hundred and fifty
+        Exception: Illegal word: "fivety"
+    """
+
+    current = result = 0
+
+    for word in x.lower().replace('-', ' ').split():
+        if word not in _ENGLISH_WRITTEN_NUMBERS and not word.isdigit():
+            # word_ = find_similar_str(word, ENGLISH_WRITTEN_NUMBERS)
+            # if word_ is None:
+            raise Exception(f"Illegal word: \"{word}\"")
+            # else:
+            #     word = word_
+
+        if word.isdigit():
+            scale, increment = (1, int(word))
+        else:
+            scale, increment = _ENGLISH_WRITTEN_NUMBERS[word]
+        current = current * scale + increment
+
+        if scale > 100:
+            result += current
+            current = 0
+
+    return result + current
+
+
 """ == Comparison of textual data ============================================================ """
 
 
@@ -183,7 +240,7 @@ def find_matched_str(x, lookup_list):
                 yield y
 
 
-def find_similar_str(x, lookup_list, n=1, ignore_punctuation=True, processor='difflib', **kwargs):
+def find_similar_str(x, lookup_list, n=1, ignore_punctuation=True, method='difflib', **kwargs):
     """
     From among a sequence of strings, find ``n`` ones that are similar to ``x``.
 
@@ -194,12 +251,12 @@ def find_similar_str(x, lookup_list, n=1, ignore_punctuation=True, processor='di
     :param n: number of similar strings to return, defaults to ``1``;
         if ``n=None``, the function returns a sorted ``lookup_list`` (in descending order of similarity)
     :type n: int or None
-    :param processor: options include ``'difflib'`` (default) and ``'fuzzywuzzy'``
+    :param method: options include ``'difflib'`` (default) and ``'fuzzywuzzy'``
 
-        - if ``processor='difflib'``, the function relies on `difflib.get_close_matches`_
-        - if ``processor='fuzzywuzzy'``, the function relies on `fuzzywuzzy.fuzz.token_set_ratio`_
+        - if ``method='difflib'``, the function relies on `difflib.get_close_matches`_
+        - if ``method='fuzzywuzzy'``, the function relies on `fuzzywuzzy.fuzz.token_set_ratio`_
 
-    :type processor: str or None
+    :type method: str or None
 
     :param ignore_punctuation: whether to ignore puctuations in the search for similar texts
     :type ignore_punctuation: bool
@@ -228,27 +285,27 @@ def find_similar_str(x, lookup_list, n=1, ignore_punctuation=True, processor='di
         ...               'Wessex',
         ...               'Western']
 
-        >>> str_similar = find_similar_str('angle', lookup_lst)
+        >>> str_similar = find_similar_str(x='angle', lookup_list=lookup_lst)
         >>> str_similar
         'Anglia'
-        >>> str_similar = find_similar_str('angle', lookup_lst, processor='fuzzywuzzy')
+        >>> str_similar = find_similar_str(x='angle', lookup_list=lookup_lst, method='fuzzywuzzy')
         >>> str_similar
         'Anglia'
 
-        >>> str_similar = find_similar_str('x', lookup_lst)
+        >>> str_similar = find_similar_str(x='x', lookup_list=lookup_lst)
         >>> str_similar  # None
 
-        >>> str_similar = find_similar_str('x', lookup_lst, processor='fuzzywuzzy')
+        >>> str_similar = find_similar_str(x='x', lookup_list=lookup_lst, method='fuzzywuzzy')
         >>> str_similar
         'Wessex'
     """
 
-    assert processor in ('difflib', 'fuzzywuzzy', None), \
+    assert method in ('difflib', 'fuzzywuzzy', None), \
         "Options for `processor` include \"difflib\" and \"fuzzywuzzy\"."
 
     m = len(lookup_list) if n is None else copy.copy(n)
 
-    if processor == 'difflib' or processor is None:
+    if method in {'difflib', None}:
         x_ = x.lower()
         lookup_dict = {y.lower(): y for y in lookup_list}
 
@@ -263,7 +320,7 @@ def find_similar_str(x, lookup_list, n=1, ignore_punctuation=True, processor='di
         else:
             sim_str = lookup_dict[sim_str_[0]]
 
-    elif processor == 'fuzzywuzzy':
+    elif method == 'fuzzywuzzy':
         import fuzzywuzzy.fuzz
 
         l_distances = [fuzzywuzzy.fuzz.token_set_ratio(s1=x, s2=a, **kwargs) for a in lookup_list]
@@ -351,10 +408,12 @@ def calculate_idf(raw_documents, rm_punc=False):
         >>> from pyhelpers.text import calculate_idf
         >>> import pandas
 
-        >>> raw_doc = pandas.Series(['This is an apple.',
-        ...                          'That is a pear.',
-        ...                          'It is human being.',
-        ...                          'Hello world!'])
+        >>> raw_doc_ = [
+        ...     'This is an apple.',
+        ...     'That is a pear.',
+        ...     'It is human being.',
+        ...     'Hello world!']
+        >>> raw_doc = pandas.Series(raw_doc_)
 
         >>> docs_tf_, corpus_idf_ = calculate_idf(raw_doc, rm_punc=False)
         >>> docs_tf_
@@ -438,10 +497,12 @@ def calculate_tf_idf(raw_documents, rm_punc=False):
         >>> from pyhelpers.text import calculate_tf_idf
         >>> import pandas
 
-        >>> raw_doc = pandas.Series(['This is an apple.',
-        ...                          'That is a pear.',
-        ...                          'It is human being.',
-        ...                          'Hello world!'])
+        >>> raw_doc_ = [
+        ...     'This is an apple.',
+        ...     'That is a pear.',
+        ...     'It is human being.',
+        ...     'Hello world!']
+        >>> raw_doc = pandas.Series(raw_doc_)
 
         >>> docs_tf_idf_ = calculate_tf_idf(raw_doc, rm_punc=False)
         >>> docs_tf_idf_
@@ -560,7 +621,7 @@ def cosine_similarity_between_texts(txt1, txt2, cosine_distance=False):
     return cos_similarity
 
 
-""" == Transformation of textual data ======================================================== """
+""" == Conversion of text files ============================================================== """
 
 
 def convert_md_to_rst(path_to_md, path_to_rst, verbose=False, pandoc_exe=None, **kwargs):
@@ -589,10 +650,10 @@ def convert_md_to_rst(path_to_md, path_to_rst, verbose=False, pandoc_exe=None, *
         >>> from pyhelpers.text import convert_md_to_rst
         >>> from pyhelpers.dir import cd
 
-        >>> dat_dir = cd("tests\\data")
+        >>> dat_dir = cd("tests\\documents")
 
-        >>> path_to_md_file = cd(dat_dir, "markdown.md")
-        >>> path_to_rst_file = cd(dat_dir, "markdown.rst")
+        >>> path_to_md_file = cd(dat_dir, "readme.md")
+        >>> path_to_rst_file = cd(dat_dir, "readme.rst")
 
         >>> convert_md_to_rst(path_to_md_file, path_to_rst_file, verbose=True)
         Converting "tests\\data\\markdown.md" to "tests\\data\\markdown.rst" ... Done.
@@ -602,30 +663,34 @@ def convert_md_to_rst(path_to_md, path_to_rst, verbose=False, pandoc_exe=None, *
     # assert abs_md_path.suffix == ".md" and abs_rst_path.suffix == ".rst"
 
     if verbose:
-        rel_md_path = pathlib.Path(os.path.relpath(abs_md_path))
-        rel_rst_path = pathlib.Path(os.path.relpath(abs_rst_path))
-        if not os.path.exists(abs_rst_path):
-            print("Converting \"{}\" to \"{}\"".format(rel_md_path, rel_rst_path), end=" ... ")
-        else:
-            print("Updating \"{}\" at \"{}\\\"".format(rel_rst_path.name, rel_rst_path.parent),
-                  end=" ... ")
+        rel_md_path, rel_rst_path = map(
+            lambda x: pathlib.Path(os.path.relpath(x)), (abs_md_path, abs_rst_path))
 
-    if pandoc_exe is None:
-        pandoc_exe = '"{}"'.format("C:\\Program Files\\Pandoc\\pandoc.exe")
-        if not os.path.isfile(pandoc_exe):
-            pandoc_exe = "pandoc"
+        if not os.path.exists(abs_rst_path):
+            msg = "Converting \"{}\" to \"{}\"".format(rel_md_path, rel_rst_path)
+        else:
+            msg = "Updating \"{}\" at \"{}\\\"".format(rel_rst_path.name, rel_rst_path.parent)
+        print(msg, end=" ... ")
+
+    pandoc_exe_ = copy.copy(pandoc_exe)
+    if pandoc_exe_ is None:
+        pandoc_exe_ = find_executable(
+            app_name="pandoc.exe", possibilities=["C:\\Program Files\\Pandoc\\pandoc.exe"])
 
     try:
         subprocess.call(
-            '{} "{}" -f markdown -t rst -s -o "{}"'.format(pandoc_exe, abs_md_path, abs_rst_path))
+            '"{}" "{}" -f markdown -t rst -s -o "{}"'.format(pandoc_exe_, abs_md_path, abs_rst_path))
 
-        print("Done.") if verbose else ""
+        if verbose:
+            print("Done.")
 
     except FileNotFoundError:
         import pypandoc
 
         pypandoc.convert_file(str(abs_md_path), 'rst', outputfile=str(abs_rst_path), **kwargs)
-        print("Done.") if verbose else ""
+
+        if verbose:
+            print("Done.")
 
     except Exception as e:
         print("Failed. {}".format(e))
